@@ -4,7 +4,9 @@ from pathlib import Path
 
 GLTEST_CONFIG_FILE = "gltest.config.yaml"
 DEFAULT_NETWORK = "localnet"
+PRECONFIGURED_NETWORKS = ["localnet", "studionet", "testnet_asimov"]
 DEFAULT_RPC_URL = SIMULATOR_JSON_RPC_URL
 DEFAULT_ENVIRONMENT = ".env"
 DEFAULT_CONTRACTS_DIR = Path("contracts")
+DEFAULT_ARTIFACTS_DIR = Path("artifacts")
 DEFAULT_NETWORK_ID = 61999
