@@ -1,5 +1,4 @@
 from gltest import get_contract_factory
-from gltest.assertions import tx_execution_succeeded
 
 
 def test_multi_file_contract(setup_validators):
@@ -7,10 +6,10 @@ def test_multi_file_contract(setup_validators):
     # Deploy Contract, it will deploy other.py as well
     setup_validators()
     factory = get_contract_factory("MultiFileContract")
-    contract = factory.deploy(args=[])
+    contract = factory.deploy(
+        args=[],
+        wait_triggered_transactions=True,
+    )
 
-    wait_response = contract.wait(args=[])
-    assert tx_execution_succeeded(wait_response)
-
-    res = contract.test(args=[])
+    res = contract.test(args=[]).call()
     assert res == "123"
