@@ -12,15 +12,15 @@ def test_storage(setup_validators):
     contract = factory.deploy(args=[INITIAL_STATE], wait_retries=40)
 
     # Get initial state
-    contract_state_1 = contract.get_storage(args=[])
+    contract_state_1 = contract.get_storage(args=[]).call()
     assert contract_state_1 == INITIAL_STATE
 
     # Update State
     transaction_response_call_1 = contract.update_storage(
-        args=[UPDATED_STATE], wait_retries=40
-    )
+        args=[UPDATED_STATE]
+    ).transact(wait_retries=40)
     assert tx_execution_succeeded(transaction_response_call_1)
 
     # Get Updated State
-    contract_state_2 = contract.get_storage(args=[])
+    contract_state_2 = contract.get_storage(args=[]).call()
     assert contract_state_2 == UPDATED_STATE
